==> mx-bootrepair_24.4.tar.xz: BUILD/translations/mx-boot-repair_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Oppstartsreparasjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Oppstartsreparasjon kan brukes til å ominstallere oppstartslasteren GRUB på ESP (EFI systempartisjon), MBR (hovedpartisjonssektor) eller rotpartisjonen. Verktøyet kan rekonstruere oppsettsfila til GRUB, og reservekopiere og gjenopprette MBR eller PBR (rot).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>Hva vil du gjøre?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Reservekopiere MBR eller PBR (kun gammel type oppstart)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Ominstallere GRUB på ESP, MBR eller PBR (rot)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Reparere oppsettsfila til GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Gjenopprette MBR eller PBR fra reservekopi (kun gammel type oppstart)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Select Boot Method</source>
        <translation>Velg oppstartsmetode</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Master Boot Record</source>
        <translation>Hovedpartisjonssektor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="160"/>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Rot (partisjonssektor)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <location filename="../mainwindow.cpp" line="564"/>
        <source>root</source>
        <translation>rot</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="236"/>
        <location filename="../mainwindow.cpp" line="563"/>
        <source>Install on:</source>
        <translation>Installer til:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="255"/>
        <location filename="../mainwindow.cpp" line="562"/>
        <source>Location:</source>
        <translation>Plassering:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.cpp" line="572"/>
        <source>Select root location:</source>
        <translation>Velg rotplassering:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>EFI System Partition</source>
        <translation>EFI-systempartisjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="293"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="420"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="423"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="472"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="482"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Cancel any changes then quit</source>
        <translation>Forkast alle endringer og avslutt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="526"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="533"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <source>Apply any changes</source>
        <translation>Ta i bruk endringene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <location filename="../mainwindow.cpp" line="93"/>
        <source>Apply</source>
        <translation>Bruk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB installeres nå på enheten %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="148"/>
        <location filename="../mainwindow.cpp" line="233"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="456"/>
        <location filename="../mainwindow.cpp" line="495"/>
        <location filename="../mainwindow.cpp" line="600"/>
        <location filename="../mainwindow.cpp" line="604"/>
        <location filename="../mainwindow.cpp" line="612"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <location filename="../mainwindow.cpp" line="625"/>
        <location filename="../mainwindow.cpp" line="678"/>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="149"/>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Klarte ikke sette opp chroot-miljø.
Dobbeltsjekk valgt plassering.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="214"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Gjenoppbygger oppsettsfila til GRUB (grub.cfg).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Reservekopierer MBR eller PBR fra enheten %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>You are going to write the content of </source>
        <translation>Nå skal innholdet i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source> to </source>
        <translation>skrives til</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="332"/>
        <source>

Are you sure?</source>
        <translation>

Er du sikker?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Gjenoppretter MBR/PBR fra reservekopi til enheten %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="359"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Fant ikke EFI systempartisjon (ESP) på noen systemdisker. Opprett en ESP og forsøk igjen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <source>Select %1 location:</source>
        <translation>Velg plasseringen til %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Fullført uten feil. &lt;p&gt;&lt;b&gt;Vil du avslutte MX Oppstartsreparasjon?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Prosessen er fullført. Det oppstod feil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Angi passord for å låse opp den krypterte partisjonen %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Klarte ikke åpne LUKS-partisjonen %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="571"/>
        <source>Select GRUB location</source>
        <translation>Velg GRUB-plassering</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Select Item to Back Up</source>
        <translation>Velg et element som skal reservekopieres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="590"/>
        <source>Select Item to Restore</source>
        <translation>Velg et element som skal gjenopprettes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="600"/>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>No location was selected.</source>
        <translation>Ingen plassering er valgt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="605"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Velg rotpartisjonen til systemet som skal fikses.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <source>Select backup file name</source>
        <translation>Velg filnavn til reservekopien</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="612"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>No file was selected.</source>
        <translation>Ingen fil ble valgt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="617"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Velg fil med MBR/PBR-reservekopi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="642"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="645"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Oppstartsreparasjon for MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="648"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Klarte ikke montere partisjonen %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>Could not create a temporary folder</source>
        <translation>Klarte ikke å opprette midlertidig mappe</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>MX Boot Repair</source>
        <translation>MX Oppstartsreparasjon</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>You must run this program with admin access.</source>
        <translation>Dette programmet må kjøres med administratorrettigheter.</translation>
    </message>
</context>
</TS>

==> mx-bootrepair_25.4.tar.xz: BUILD/translations/mx-boot-repair_nb.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Oppstartsreparasjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="45"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Oppstartsreparasjon kan brukes til å ominstallere oppstartslasteren GRUB på ESP (EFI systempartisjon), MBR (hovedpartisjonssektor) eller rotpartisjonen. Verktøyet kan rekonstruere oppsettsfila til GRUB, og reservekopiere og gjenopprette MBR eller PBR (rot).</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>What would you like to do?</source>
        <translation>Hva vil du gjøre?</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="94"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Reservekopiere MBR eller PBR (kun gammel type oppstart)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Ominstallere GRUB på ESP, MBR eller PBR (rot)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Repair GRUB configuration file</source>
        <translation>Reparere oppsettsfila til GRUB</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Regenerate initramfs images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Gjenopprette MBR eller PBR fra reservekopi (kun gammel type oppstart)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <location filename="../mainwindow.cpp" line="599"/>
        <source>Select Boot Method</source>
        <translation>Velg oppstartsmetode</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="152"/>
        <source>Master Boot Record</source>
        <translation>Hovedpartisjonssektor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="193"/>
        <location filename="../mainwindow.cpp" line="600"/>
        <source>Location:</source>
        <translation>Plassering:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>EFI System Partition</source>
        <translation>EFI-systempartisjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Rot (partisjonssektor)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>root</source>
        <translation>rot</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Select root location:</source>
        <translation>Velg rotplassering:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="300"/>
        <location filename="../mainwindow.cpp" line="601"/>
        <source>Install on:</source>
        <translation>Installer til:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="389"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="449"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>Cancel any changes then quit</source>
        <translation>Forkast alle endringer og avslutt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="518"/>
        <source>Apply any changes</source>
        <translation>Ta i bruk endringene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="521"/>
        <location filename="../mainwindow.cpp" line="84"/>
        <source>Apply</source>
        <translation>Bruk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB installeres nå på enheten %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="138"/>
        <location filename="../mainwindow.cpp" line="221"/>
        <location filename="../mainwindow.cpp" line="277"/>
        <location filename="../mainwindow.cpp" line="397"/>
        <location filename="../mainwindow.cpp" line="489"/>
        <location filename="../mainwindow.cpp" line="527"/>
        <location filename="../mainwindow.cpp" line="638"/>
        <location filename="../mainwindow.cpp" line="642"/>
        <location filename="../mainwindow.cpp" line="649"/>
        <location filename="../mainwindow.cpp" line="655"/>
        <location filename="../mainwindow.cpp" line="663"/>
        <location filename="../mainwindow.cpp" line="670"/>
        <location filename="../mainwindow.cpp" line="722"/>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../mainwindow.cpp" line="222"/>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Klarte ikke sette opp chroot-miljø.
Dobbeltsjekk valgt plassering.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="202"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>Gjenoppbygger oppsettsfila til GRUB (grub.cfg).</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="238"/>
        <source>Generating initramfs images on: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Reservekopierer MBR eller PBR fra enheten %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>You are going to write the content of </source>
        <translation>Nå skal innholdet i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source> to </source>
        <translation>skrives til</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>

Are you sure?</source>
        <translation>

Er du sikker?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Gjenoppretter MBR/PBR fra reservekopi til enheten %1.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Fant ikke EFI systempartisjon (ESP) på noen systemdisker. Opprett en ESP og forsøk igjen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Select %1 location:</source>
        <translation>Velg plasseringen til %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>Success</source>
        <translation>Vellykket</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Fullført uten feil. &lt;p&gt;&lt;b&gt;Vil du avslutte MX Oppstartsreparasjon?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Prosessen er fullført. Det oppstod feil.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Angi passord for å låse opp den krypterte partisjonen %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>Sorry, could not open %1 LUKS container</source>
        <translation>Klarte ikke åpne LUKS-partisjonen %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="606"/>
        <source>Select GRUB location</source>
        <translation>Velg GRUB-plassering</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Select initramfs options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Select Item to Back Up</source>
        <translation>Velg et element som skal reservekopieres</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Select Item to Restore</source>
        <translation>Velg et element som skal gjenopprettes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="638"/>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>No location was selected.</source>
        <translation>Ingen plassering er valgt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <location filename="../mainwindow.cpp" line="656"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Velg rotpartisjonen til systemet som skal fikses.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>Select backup file name</source>
        <translation>Velg filnavn til reservekopien</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>No file was selected.</source>
        <translation>Ingen fil ble valgt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Velg fil med MBR/PBR-reservekopi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Oppstartsreparasjon for MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="692"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>Sorry, could not mount %1 partition</source>
        <translation>Klarte ikke montere partisjonen %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="733"/>
        <source>Could not create a temporary folder</source>
        <translation>Klarte ikke å opprette midlertidig mappe</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>MX Boot Repair</source>
        <translation>MX Oppstartsreparasjon</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>You must run this program with admin access.</source>
        <translation>Dette programmet må kjøres med administratorrettigheter.</translation>
    </message>
</context>
</TS>
